/***********************************************************************************************************************
 *
 * blueBill Mobile - open source birdwatching
 * ==========================================
 *
 * Copyright (C) 2009, 2010 by Tidalwave s.a.s. (http://www.tidalwave.it)
 * http://bluebill.tidalwave.it/mobile/
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * $Id: DefaultGeneralPreferences.java,v 7f0d5e8da985 2010/06/26 23:21:53 fabrizio $
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.mobile;

import javax.annotation.Nonnull;
import java.util.Date;
import java.util.Locale;
import java.text.SimpleDateFormat;
import org.openide.util.NbBundle;
import org.openide.util.lookup.ServiceProvider;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id: $
 *
 **********************************************************************************************************************/
@ServiceProvider(service=GeneralPreferences.class)
public class DefaultGeneralPreferences implements GeneralPreferences
  {
    @Nonnull
    public String formatDateAndTime (final @Nonnull Date date)
      {
        final String pattern = NbBundle.getMessage(DefaultGeneralPreferences.class, "dateTimePattern");
        String string = new SimpleDateFormat(pattern).format(date);
        //
        // On Android 1.5, some piece of equipment doesn't have all the locale date symbols. See BBMA-81
        //
        if (!containsAlpha(string))
          {
            string = new SimpleDateFormat("d/M - HH:mm", Locale.US).format(date);
          }

        return string;
      }

    @Nonnull
    public String formatDateAndTime (final @Nonnull Date date,
                                     final @Nonnull String prefix,
                                     final @Nonnull String postfix)
      {
        return String.format("%s%s%s", prefix, formatDateAndTime(date), postfix);
      }

    @Nonnull
    public String formatTime (final @Nonnull Date date)
      {
        final String pattern = NbBundle.getMessage(DefaultGeneralPreferences.class, "timePattern");
        return new SimpleDateFormat(pattern).format(date);
      }

    private static boolean containsAlpha (final @Nonnull String string)
      {
        for (int i = 0; i < string.length(); i++)
          {
            final char c = string.charAt(i);

            if (Character.isLetter(c) && Character.isLowerCase(c)) // lowercase to avoid matching AM or PM
              {
                return true;
              }
          }

        return false;
      }
  }
